<?php
/*
  Plugin Name: subiz
  Plugin URI: http://support.subiz.com/support/solutions/articles/76904-subiz-plugins
  Description: Subiz live chat plugin offers an excellent customer interaction platform where sales and customer service team can communicate directly with visitors, fulfil any enquiry in real-time, and actively receive feedback
  Version: 4.0
  Author: mrsubiz
  Author URI: http://subiz.com
  License: GPL3
 */
if(!class_exists('Subiz_Settings')){

	class Subiz_Settings{
		const SUBIZ_LICENCE_ID_VARIABLE = 'subiz_licence_id';
		const SUBIZ_VISIBILITY_OPTIONS = 'subiz-visibility-options';

		public function __construct(){

			if(!get_option('subiz-visibility-options',false))
			{
			$visibility = array (
				'subiz_widget_color'=>'',
				'subiz_widget_button' => '',
				'image_attachment_id' => '',
				'image_attachment_id_2' => '',
				'image_attachment_id_3' => '',
				'subiz_notify_setting' => '',
				'subiz_notify_text' => '',
				'subiz_widget_button_width' => '',
				'subiz_noti_button_default_l' => '',
				'subiz_noti_button_default_r' => '',
				'revert_default_l' => '',
				'revert_default_r' => '',
			);
			update_option( 'subiz-visibility-options', $visibility);
			}
			add_action('admin_init', array(&$this, 'admin_init'));
			add_action('admin_menu', array(&$this, 'add_menu'));
			add_action('admin_enqueue_scripts', array($this,'subiz_settings_assets') );
		}

		public function subiz_settings_assets($hook)
		{
			if($hook != 'settings_page_subiz_plugin')
				return;

				wp_register_style( 'subiz_admin_style', plugins_url( 'assets/admin.css' , __FILE__ ) );
				wp_enqueue_style( 'subiz_admin_style' );
				wp_register_style( 'subiz_ui_style', plugins_url( 'assets/vendor/jquery-ui/jquery-ui.min.css' , __FILE__ ) );
				wp_enqueue_style( 'subiz_ui_style' );
				wp_register_style( 'subiz_colorpicker_style', plugins_url( 'assets/vendor/colorpicker-master/css/evol-colorpicker.min.css' , __FILE__ ) );
				wp_enqueue_style( 'subiz_colorpicker_style' );
				wp_enqueue_script( 'subiz_ui_script', plugins_url( 'assets/vendor/jquery-ui/jquery-ui.min.js' , __FILE__ ) );
				wp_enqueue_script( 'subiz_colorpicker_script', plugins_url( 'assets/vendor/colorpicker-master/js/evol-colorpicker.min.js' , __FILE__ ) );
				wp_enqueue_script( 'subiz_admin_script', plugins_url( 'assets/admin.js' , __FILE__ ) );

		}

		public function admin_init(){
			register_setting( 'subiz_options', 'subiz_licence_id');
			register_setting( 'subiz_options', 'subiz-visibility-options', array(&$this,'validate_options') );
		}



		public function validate_options($input){
			$input['subiz_widget_color'] = sanitize_hex_color($input['subiz_widget_color']);
			$input['subiz_widget_button'] = sanitize_text_field($input['subiz_widget_button']);
			$input['image_attachment_id'] = absint($input['image_attachment_id']);
			$input['image_attachment_id_2'] = absint($input['image_attachment_id_2']);
			$input['image_attachment_id_3'] = absint($input['image_attachment_id_3']);
			$input['subiz_notify_setting'] = sanitize_text_field($input['subiz_notify_setting']);
			$input['subiz_notify_text'] = sanitize_textarea_field($input['subiz_notify_text']);
			$input['subiz_widget_button_width'] = absint($input['subiz_widget_button_width']);
			$input['subiz_noti_button_default_l'] = sanitize_text_field($input['subiz_noti_button_default_l']);
			$input['subiz_noti_button_default_r'] = sanitize_text_field($input['subiz_noti_button_default_r']);
			$input['revert_default_l'] = sanitize_text_field($input['revert_default_l']);
			$input['revert_default_r'] = sanitize_text_field($input['revert_default_r']);
			return $input;
		}

		public function add_menu(){
			add_options_page(
				__('Subiz Settings','subiz'),
				__('Subiz','subiz'),
				'manage_options',
				'subiz_plugin',
				array(&$this, 'create_plugin_settings_page')
			);
		}


		public function create_plugin_settings_page(){

			global $wpdb;

			if(!current_user_can('manage_options'))	{
				wp_die(__('You do not have sufficient permissions to access this page.'));
			}


			include(sprintf("%s/templates/settings.php", dirname(__FILE__)));
		}

	}
}

if(!class_exists('Subiz')){
	class Subiz{
		public function __construct(){
			$subiz_settings = new Subiz_Settings();
		}

		public static function activate(){

			$visibility = array (
				'subiz_widget_color' => '',
				'subiz_widget_color'=>'',
				'subiz_widget_button' => '',
				'image_attachment_id' => '',
				'image_attachment_id_2' => '',
				'image_attachment_id_3' => '',
				'subiz_notify_setting' => '',
				'subiz_notify_text' => '',
				'subiz_widget_button_width' => '',
				'subiz_noti_button_default_l' => '',
				'subiz_noti_button_default_r' => '',
				'revert_default_l' => '',
				'revert_default_r' => '',
			);

			add_option(Subiz_Settings::SUBIZ_LICENCE_ID_VARIABLE, '', '', 'yes');
			add_option(Subiz_Settings::SUBIZ_VISIBILITY_OPTIONS, $visibility, '', 'yes');
		}

		public static function deactivate(){
			delete_option(Subiz_Settings::SUBIZ_LICENCE_ID_VARIABLE, '', '', 'yes');
			delete_option(Subiz_Settings::SUBIZ_VISIBILITY_OPTIONS);
		}



		public function sfw_insert_code(){
			$visibility = get_option( 'subiz-visibility-options' );
			$subiz_licence_id = get_option('subiz_licence_id');
	    echo "<!-- Subiz --> <script> (function(s, u, b, i, z){ u[i]=u[i]||function(){ u[i].t=+new Date(); (u[i].q=u[i].q||[]).push(arguments); }; z=s.createElement('script'); var zz=s.getElementsByTagName('script')[0]; z.async=1; z.src=b; z.id='subiz-script'; zz.parentNode.insertBefore(z,zz); })(document, window, 'https://widgetv4.subiz.com/static/js/app.js', 'subiz'); subiz('setAccount', '" . $subiz_licence_id . "'); </script> <!-- End Subiz -->";
	    $subiz_widget_color = $visibility['subiz_widget_color'];
	    $subiz_notify_setting = $visibility['subiz_notify_setting'];
	    $subiz_notify_text = $visibility['subiz_notify_text'];
	    if( $subiz_notify_text == ""){
	      if(get_locale() == "vi"){
	        $subiz_notify_text = "Click vào ĐỒNG Ý để nhận các thông tin hữu ích từ Subiz";
	      }else{
	        $subiz_notify_text = "Click AGREE to get useful information from SUBIZ";
	      }
	    }
	    if($subiz_widget_color){
	      echo "<script type=\"text/javascript\">
	                window.subiz('changeCss', '.color-theme-default{background-color:".$subiz_widget_color." !important;}')
	            </script>";
	    };
	    if ($subiz_notify_setting == 's1') {
	      $image = ($visibility['media_selector_attachment_id' ] != '') ? wp_get_attachment_url($visibility['media_selector_attachment_id']) : plugins_url( 'subiz_logo.png' , __FILE__ );
	      echo ("<style type=\"text/css\">
	            @import url('https://fonts.googleapis.com/css?family=Muli:300,400,700&subset=latin-ext,vietnamese');
	            body{margin:0px; padding: 0px;font-family: 'Muli', sans-serif; font-weight: 400; font-size: 16px; color: #4a4a4a; -webkit-font-smoothing: antialiased; -moz-osx-font-smoothing: grayscale;}
	            *{box-sizing: border-box;}
	            .popup-subscribire{position: fixed; top: 30px; width:500px; left: 50%; margin-left:-250px; padding: 18px; border-radius: 3px; background: #FFF; box-shadow: 0px 0px 20px rgba(5,25,62, .15);z-index:100;display: block;}
	            .popup-logo{ display: inline-block; vertical-align: top; width:120px; margin-right:20px;}
	            .popup-logo img{max-width:100%;}
	            .popup-summary{display: inline-block; width:calc(100% - 120px - 25px); line-height: 21px;}
	            .popup-bottom{position: relative; width:100%; padding: 5px 0 0 0; text-align: right;}
	            .popup-bottom a{ display: inline-block;vertical-align: middle; margin:0 3px; height: 40px; line-height: 38px; padding: 0 25px; color: #1890ff; font-size: 16px; font-weight:500; text-transform: uppercase; text-decoration: none; border-radius: 3px;}
	            .popup-bottom a.ok{ color: #FFF; background-color: #1890ff;}
	            </style>
	            ​
	            <div class=\"popup-subscribire\">
	              <div class=\"popup-logo\"><img src=\"". $image."\"></div>
	              <div class=\"popup-summary\">".$subiz_notify_text."</div>
	              <div class=\"popup-bottom\">
	                <a href=\"#\" onclick=\"closePopUp();\">".__('No, thanks', 'subiz')."</a>
	                <a href=\"#\" class=\"ok\" onclick=\"subiz('subscribePushNotification');closePopUp()\">".__('Agree', 'subiz')."</a>
	              </div>
	            </div>
	            ​
	            <script type=\"text/javascript\">
	              function closePopUp(e) {
	                document.querySelector('.popup-subscribire').style.display = 'none'
	                if ( typeof(Storage) !== 'undefined') {
	                    sessionStorage.setItem('closePopUp', 1);
	                }
	              };

	            </script>");
	    } elseif ($subiz_notify_setting == 's2') {
	      if($visibility['revert_default_r'] == "set"){
	        if($visibility['subiz_noti_button_default_r']){
	          $image2 =  $visibility['subiz_noti_button_default_r'];
	        }else{
	          $image2 = plugins_url("../assets/buttons/right/default_1_".get_locale().".png" , __FILE__ );
	        }
	      }else{
	        if($visibility['image_attachment_id_2'] != ''){
	          $image2 = wp_get_attachment_url($visibility['image_attachment_id_2']);
	        }
	      }
	      echo "<style type=\"text/css\">
	            .popup-subscribire{position: fixed; top: 50%; right: 0px; z-index:100;display: block;}

	            </style>
	            ​
	            <div class=\"popup-subscribire\">
	              <a href=\"#\" class=\"ok\" onclick=\"subiz('subscribePushNotification');closePopUp()\">

	                <img src=\"". $image2."\"></div>
	              </a>
	              </div>
	            </div>";

	    } elseif ($subiz_notify_setting == 's3') {
	      if($visibility['revert_default_l'] == "set"){
	        if($visibility['subiz_noti_button_default_l']){
	          $image3 =  $visibility['subiz_noti_button_default_l'];
	        }else{
	          $image3 = plugins_url("../assets/buttons/left/default_1_".get_locale().".png" , __FILE__ );
	        }
	      }else{
	        if($visibility['image_attachment_id_3'] != ''){
	          $image3 = wp_get_attachment_url($visibility['image_attachment_id_3']);
	        }
	      }
	    echo "<style type=\"text/css\">
	                  .popup-subscribire{position: fixed; top: 50%; left: 0px; z-index:100;display: block;}

	                  </style>
	                  ​
	                  <div class=\"popup-subscribire\">
	                    <a href=\"#\" class=\"ok\" onclick=\"subiz('subscribePushNotification');closePopUp()\">
	                      <img src=\"". $image3."\"></div>
	                    </a>
	                    </div>
	                  </div>";

	    }
	    if($visibility['subiz_widget_button']){
	      if($visibility['subiz_widget_button_width'] == 60){
	        echo "<script type=\"text/javascript\"> window.subiz('changeCss', '.button-chat{ border-radius:  0;  -webkit-mask-image:  url(".$visibility['subiz_widget_button']."); }  .button-chat-icon{  display:  none;}  @supports  (-ms-ime-align:auto)  {  .button-chat{border-radius:50%;}  .button-chat-icon{  display:  inline-block;}  }') </script>";
	      }else{
	        echo "<script type=\"text/javascript\"> window.subiz('changeCss', '.button-chat-icon{display:none}@supports (-ms-ime-align:auto){.button-chat{border-radius:50%}.button-chat-icon{display:inline-block}}.widget-button{width:240px;height:146px}.button-chat{background-image:url(".$visibility['subiz_widget_button'].");background-repeat:no-repeat;-webkit-mask-image: none;border-radius:0!important;box-shadow: none;background-color: transparent !important;position: inherit;}.button-chat .avatar-preview img,.widget-button:after,.widget_mini .close-widget-icon{display:none}') </script>";
	      }
	    };
		}
}}

if(class_exists('Subiz')){
	register_activation_hook(__FILE__, array('Subiz', 'activate'));
	register_deactivation_hook(__FILE__, array('Subiz', 'deactivate'));

	$subiz = new Subiz();


	add_action('wp_footer',  array($subiz, 'sfw_insert_code'));
}
